@@ -31,72 +31,72 @@ __all__ = [
 
 
 class ImageExtensions(str, Enum):
-    blp = '.blp'
-    bmp = '.bmp'
-    dib = '.dib'
-    bufr = '.bufr'
-    cur = '.cur'
-    pcx = '.pcx'
-    dcx = '.dcx'
-    dds = '.dds'
-    ps = '.ps'
-    eps = '.eps'
-    fit = '.fit'
-    fits = '.fits'
-    fli = '.fli'
-    flc = '.flc'
-    ftc = '.ftc'
-    ftu = '.ftu'
-    gbr = '.gbr'
-    gif = '.gif'
-    grib = '.grib'
-    h5 = '.h5'
-    hdf = '.hdf'
-    png = '.png'
-    apng = '.apng'
-    jp2 = '.jp2'
-    j2k = '.j2k'
-    jpc = '.jpc'
-    jpf = '.jpf'
-    jpx = '.jpx'
-    j2c = '.j2c'
-    icns = '.icns'
-    ico = '.ico'
-    im = '.im'
-    iim = '.iim'
-    tif = '.tif'
-    tiff = '.tiff'
-    jfif = '.jfif'
-    jpe = '.jpe'
-    jpg = '.jpg'
-    jpeg = '.jpeg'
-    mpg = '.mpg'
-    mpeg = '.mpeg'
-    mpo = '.mpo'
-    msp = '.msp'
-    palm = '.palm'
-    pcd = '.pcd'
-    pdf = '.pdf'
-    pxr = '.pxr'
-    pbm = '.pbm'
-    pgm = '.pgm'
-    ppm = '.ppm'
-    pnm = '.pnm'
-    psd = '.psd'
-    bw = '.bw'
-    rgb = '.rgb'
-    rgba = '.rgba'
-    sgi = '.sgi'
-    ras = '.ras'
-    tga = '.tga'
-    icb = '.icb'
-    vda = '.vda'
-    vst = '.vst'
-    webp = '.webp'
-    wmf = '.wmf'
-    emf = '.emf'
-    xbm = '.xbm'
-    xpm = '.xpm'
+    blp = 'blp'
+    bmp = 'bmp'
+    dib = 'dib'
+    bufr = 'bufr'
+    cur = 'cur'
+    pcx = 'pcx'
+    dcx = 'dcx'
+    dds = 'dds'
+    ps = 'ps'
+    eps = 'eps'
+    fit = 'fit'
+    fits = 'fits'
+    fli = 'fli'
+    flc = 'flc'
+    ftc = 'ftc'
+    ftu = 'ftu'
+    gbr = 'gbr'
+    gif = 'gif'
+    grib = 'grib'
+    h5 = 'h5'
+    hdf = 'hdf'
+    png = 'png'
+    apng = 'apng'
+    jp2 = 'jp2'
+    j2k = 'j2k'
+    jpc = 'jpc'
+    jpf = 'jpf'
+    jpx = 'jpx'
+    j2c = 'j2c'
+    icns = 'icns'
+    ico = 'ico'
+    im = 'im'
+    iim = 'iim'
+    tif = 'tif'
+    tiff = 'tiff'
+    jfif = 'jfif'
+    jpe = 'jpe'
+    jpg = 'jpg'
+    jpeg = 'jpeg'
+    mpg = 'mpg'
+    mpeg = 'mpeg'
+    mpo = 'mpo'
+    msp = 'msp'
+    palm = 'palm'
+    pcd = 'pcd'
+    pdf = 'pdf'
+    pxr = 'pxr'
+    pbm = 'pbm'
+    pgm = 'pgm'
+    ppm = 'ppm'
+    pnm = 'pnm'
+    psd = 'psd'
+    bw = 'bw'
+    rgb = 'rgb'
+    rgba = 'rgba'
+    sgi = 'sgi'
+    ras = 'ras'
+    tga = 'tga'
+    icb = 'icb'
+    vda = 'vda'
+    vst = 'vst'
+    webp = 'webp'
+    wmf = 'wmf'
+    emf = 'emf'
+    xbm = 'xbm'
+    xpm = 'xpm'
 
 
 
