@@ -19,6 +19,7 @@ from ..Enumerations import *
 from ..Widgets.base import *
 from ...Files import Path
 from ...Images import *
+from ...Json import Size
 
 
 
@@ -46,7 +47,7 @@ class BindingCollection(dict, Dict[Bindings, Set[str]]):
 
 class BaseTkinterWidget(tk.Widget, ABC):
     # noinspection PyMissingConstructor
-    def __init__(self, Color: dict = None, ):
+    def __init__(self, Color: dict = None):
         if Color: self.configure(**Color)
 
     __bindings__: BindingCollection = BindingCollection()
@@ -109,7 +110,7 @@ class BaseTkinterWidget(tk.Widget, ABC):
     @property
     def y(self) -> int: return self.winfo_rooty()
 
-
+    def size(self) -> Size: return Size.Create(self.width, self.height)
     def show(self, **kwargs) -> bool:
         """
         Shows the current widget or _root_frame, based on the current geometry manager.
@@ -489,10 +490,10 @@ class CommandMixin:
         :type func: Union[callable, FunctionType, MethodType, CurrentValue]
         :param z: arg passed to the fucntion.
         :type z: Union[int, float, str, Enum]
-        :param add: if False, replaces the current function.
+        :param add: if True, replaces the current function.
         :type add: bool
         :param kwargs: keyword args passed to the function.
-        :type kwargs: Dict[str, Any]
+        :type kwargs: Any
         :return: returns self to enable chaining.
         """
         if not callable(func):
@@ -517,8 +518,11 @@ class ImageMixin:
         return self._open(ImageObject.FromFile(path, width=WidthMax, height=HeightMax))
         # with open(path, 'rb') as f:
         #     return self._open(f, WidthMax, HeightMax)
-    def SetPhoto(self, base64Data: bytes or str = None, *, WidthMax: int = None, HeightMax: int = None):
-        return self._open(ImageObject.FromBase64(base64Data, width=WidthMax, height=HeightMax))
+    def SetPhoto(self, data: Union[str, bytes], *ext: ImageExtensions, WidthMax: int = None, HeightMax: int = None):
+        if isinstance(data, bytes):
+            return self._open(ImageObject.FromBytes(data, *ext, width=WidthMax, height=HeightMax))
+
+        return self._open(ImageObject.FromBase64(data, *ext, width=WidthMax, height=HeightMax))
         # with io.BytesIO(base64.b64decode(base64Data)) as buf:
         #     return self._open(buf)
     def DownloadImage(self, url: str, *, WidthMax: int = None, HeightMax: int = None):
